@@ -72,6 +72,11 @@ class InfEngineServer:
     ):
         """ Class that handles InfEngineServer commands. """
 
+        # Create directories
+        Path(self.root_path / INF_ENGINE_PATH_TMP).mkdir(exist_ok=True)
+        Path(self.root_path / INF_ENGINE_PATH_LOGS).mkdir(exist_ok=True)
+        Path(self.root_path / "release" / "dldata").mkdir(exist_ok=True)
+
         # Determine the root path
         if root_path:
             self.root_path = Path(root_path)
@@ -95,15 +100,16 @@ class InfEngineServer:
             datefmt="%Y.%m.%d %H:%M:%S",
         )
 
-        if enable_logging:
-            log_file_name = Path(self.root_path / INF_ENGINE_LOG_FILE_PATH)
-            log_file_name.touch(exist_ok=True)
-            handler = logging.FileHandler(
-                filename=Path(self.root_path / INF_ENGINE_LOG_FILE_PATH)
-            )
-            handler.setFormatter(formatter)
-            self._logger.addHandler(handler)
+        log_file_name = Path(self.root_path / INF_ENGINE_LOG_FILE_PATH)
+        log_file_name.touch(exist_ok=True)
 
+        handler = logging.FileHandler(
+            filename=Path(self.root_path / INF_ENGINE_LOG_FILE_PATH)
+        )
+        handler.setFormatter(formatter)
+        self._logger.addHandler(handler)
+
+        if enable_logging:
             handler = logging.StreamHandler()
             handler.setFormatter(formatter)
             self._logger.addHandler(handler)
